@@ -1,4 +1,4 @@
-/* Copyright 1995-2004,2006,2009-2014,2016-2019
+/* Copyright 1995-2004,2006,2009-2014,2016-2020
      Free Software Foundation, Inc.
 
    This file is part of Guile.
@@ -137,7 +137,6 @@
 #include "symbols.h"
 #include "syntax.h"
 #include "throw.h"
-#include "trees.h"
 #include "unicode.h"
 #include "uniform.h"
 #include "values.h"
@@ -156,49 +155,19 @@
 
 /* initializing standard and current I/O ports */
 
-typedef struct
-{
-  int fdes;
-  char *mode;
-} stream_body_data;
-
-/* proc to be called in scope of exception handler stream_handler. */
-static SCM
-stream_body (void *data)
-{
-  stream_body_data *body_data = (stream_body_data *) data;
-  SCM port = scm_fdes_to_port (body_data->fdes, body_data->mode, SCM_BOOL_F);
-  scm_set_port_revealed_x (port, SCM_INUM1);
-  return port;
-}
-
-/* exception handler for stream_body.  */
-static SCM
-stream_handler (void *data SCM_UNUSED,
-		SCM tag SCM_UNUSED,
-		SCM throw_args SCM_UNUSED)
-{
-  return SCM_BOOL_F;
-}
-
 /* Convert a file descriptor to a port, using scm_fdes_to_port.
    - set the revealed count for FILE's file descriptor to 1, so
-   that fdes won't be closed when the port object is GC'd.
-   - catch exceptions: allow Guile to be able to start up even
-   if it has been handed bogus stdin/stdout/stderr.  replace the
-   bad ports with void ports.  */
+   that fdes won't be closed when the port object is GC'd.  */
 static SCM
 scm_standard_stream_to_port (int fdes, char *mode)
 {
-  SCM port;
-  stream_body_data body_data;
+  long mode_bits = scm_mode_bits (mode);
 
-  body_data.fdes = fdes;
-  body_data.mode = mode;
-  port = scm_internal_catch (SCM_BOOL_T, stream_body, &body_data, 
-			     stream_handler, NULL);
-  if (scm_is_false (port))
-    port = scm_void_port (mode);
+  if (!scm_i_fdes_is_valid (fdes, mode_bits))
+    return scm_void_port (mode);
+
+  SCM port = scm_i_fdes_to_port (fdes, mode_bits, SCM_BOOL_F, 0);
+  scm_set_port_revealed_x (port, SCM_INUM1);
   return port;
 }
 
@@ -492,7 +461,6 @@ scm_i_init_guile (void *base)
   scm_init_srfi_14 ();  /* Requires smob_prehistory */
   scm_init_exceptions ();
   scm_init_throw ();    /* Requires smob_prehistory */
-  scm_init_trees ();
   scm_init_version ();
   scm_init_weak_set ();
   scm_init_weak_table ();
