@@ -1,6 +1,4 @@
-/* srfi-13.c --- SRFI-13 procedures for Guile
-
-   Copyright 2001,2004-2006,2008-2012,2018
+/* Copyright 2001,2004-2006,2008-2013,2017-2019
      Free Software Foundation, Inc.
 
    This file is part of Guile.
@@ -62,7 +60,7 @@
   } while (0)
 
 #define REF_IN_CHARSET(s, i, cs)					\
-  (scm_is_true (scm_char_set_contains_p ((cs), SCM_MAKE_CHAR (scm_i_string_ref (s, i)))))
+  (scm_is_true (scm_char_set_contains_p ((cs), scm_c_make_char (scm_i_string_ref (s, i)))))
 
 SCM_DEFINE (scm_string_null_p, "string-null?", 1, 0, 0,
            (SCM str),
@@ -142,7 +140,7 @@ SCM_DEFINE (scm_string_any, "string-any-c-code", 2, 2, 0,
       while (cstart < cend)
         {
           res = scm_call_1 (char_pred, 
-                            SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)));
+                            scm_c_make_char (scm_i_string_ref (s, cstart)));
           if (scm_is_true (res))
             break;
           cstart++;
@@ -209,7 +207,7 @@ SCM_DEFINE (scm_string_every, "string-every-c-code", 2, 2, 0,
       while (cstart < cend)
         {
           res = scm_call_1 (char_pred, 
-                            SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)));
+                            scm_c_make_char (scm_i_string_ref (s, cstart)));
           if (scm_is_false (res))
             break;
           cstart++;
@@ -384,11 +382,12 @@ SCM_SYMBOL (scm_sym_prefix, "prefix");
 
 SCM_DEFINE (scm_string_join, "string-join", 1, 2, 0,
             (SCM ls, SCM delimiter, SCM grammar),
-	    "Append the string in the string list @var{ls}, using the string\n"
-	    "@var{delimiter} as a delimiter between the elements of @var{ls}.\n"
-	    "@var{grammar} is a symbol which specifies how the delimiter is\n"
-	    "placed between the strings, and defaults to the symbol\n"
-	    "@code{infix}.\n"
+            "Append the string in the string list @var{ls}, using the string\n"
+            "@var{delimiter} as a delimiter between the elements of @var{ls}.\n"
+            "@var{delimiter} defaults to @w{@samp{ }}, that is, strings in @var{ls}\n"
+            "are appended with the space character in between them.  @var{grammar} is\n"
+            "a symbol which specifies how the delimiter is placed between the\n"
+            "strings, and defaults to the symbol @code{infix}.\n"
 	    "\n"
 	    "@table @code\n"
 	    "@item infix\n"
@@ -415,7 +414,7 @@ SCM_DEFINE (scm_string_join, "string-join", 1, 2, 0,
   /* Validate the delimiter and record its length.  */
   if (SCM_UNBNDP (delimiter))
     {
-      delimiter = scm_from_locale_string (" ");
+      delimiter = scm_from_utf8_string (" ");
       delimiter_len = 1;
     }
   else
@@ -767,7 +766,7 @@ SCM_DEFINE (scm_string_trim, "string-trim", 1, 3, 0,
 	{
 	  SCM res;
 
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cstart)));
 	  if (scm_is_false (res))
 	    break;
 	  cstart++;
@@ -843,7 +842,7 @@ SCM_DEFINE (scm_string_trim_right, "string-trim-right", 1, 3, 0,
 	{
 	  SCM res;
 
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cend - 1)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cend - 1)));
 	  if (scm_is_false (res))
 	    break;
 	  cend--;
@@ -937,7 +936,7 @@ SCM_DEFINE (scm_string_trim_both, "string-trim-both", 1, 3, 0,
 	{
 	  SCM res;
 
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cstart)));
 	  if (scm_is_false (res))
 	    break;
 	  cstart++;
@@ -946,7 +945,7 @@ SCM_DEFINE (scm_string_trim_both, "string-trim-both", 1, 3, 0,
 	{
 	  SCM res;
 
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cend - 1)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cend - 1)));
 	  if (scm_is_false (res))
 	    break;
 	  cend--;
@@ -1707,7 +1706,7 @@ SCM_DEFINE (scm_string_index, "string-index", 2, 2, 0,
       while (cstart < cend)
 	{
 	  SCM res;
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cstart)));
 	  if (scm_is_true (res))
 	    goto found;
 	  cstart++;
@@ -1773,7 +1772,7 @@ SCM_DEFINE (scm_string_index_right, "string-index-right", 2, 2, 0,
 	{
 	  SCM res;
 	  cend--;
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cend)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cend)));
 	  if (scm_is_true (res))
 	    goto found;
 	}
@@ -1859,7 +1858,7 @@ SCM_DEFINE (scm_string_skip, "string-skip", 2, 2, 0,
       while (cstart < cend)
 	{
 	  SCM res;
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cstart)));
 	  if (scm_is_false (res))
 	    goto found;
 	  cstart++;
@@ -1926,7 +1925,7 @@ SCM_DEFINE (scm_string_skip_right, "string-skip-right", 2, 2, 0,
 	{
 	  SCM res;
 	  cend--;
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cend)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cend)));
 	  if (scm_is_false (res))
 	    goto found;
 	}
@@ -1992,7 +1991,7 @@ SCM_DEFINE (scm_string_count, "string-count", 2, 2, 0,
       while (cstart < cend)
 	{
 	  SCM res;
-	  res = scm_call_1 (char_pred, SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)));
+	  res = scm_call_1 (char_pred, scm_c_make_char (scm_i_string_ref (s, cstart)));
 	  if (scm_is_true (res))
 	    count++;
 	  cstart++;
@@ -2249,7 +2248,7 @@ string_titlecase_x (SCM str, size_t start, size_t end)
       str = scm_i_string_start_writing (str);
       for(i = start; i < end;  i++)
         {
-          ch = SCM_MAKE_CHAR (scm_i_string_ref (str, i));
+          ch = scm_c_make_char (scm_i_string_ref (str, i));
           if (scm_is_true (scm_char_alphabetic_p (ch)))
             {
               if (!in_word)
@@ -2347,7 +2346,7 @@ string_reverse_x (SCM str, size_t cstart, size_t cend)
           cend--;
           while (cstart < cend)
             {
-              tmp = SCM_MAKE_CHAR (scm_i_string_ref (str, cstart));
+              tmp = scm_c_make_char (scm_i_string_ref (str, cstart));
               scm_i_string_set_x (str, cstart, scm_i_string_ref (str, cend));
               scm_i_string_set_x (str, cend, SCM_CHAR (tmp));
               cstart++;
@@ -2584,7 +2583,7 @@ SCM_DEFINE (scm_string_fold, "string-fold", 3, 2, 0,
   result = knil;
   while (cstart < cend)
     {
-      result = scm_call_2 (kons, SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)), result);
+      result = scm_call_2 (kons, scm_c_make_char (scm_i_string_ref (s, cstart)), result);
       cstart++;
     }
 
@@ -2612,7 +2611,7 @@ SCM_DEFINE (scm_string_fold_right, "string-fold-right", 3, 2, 0,
   result = knil;
   while (cstart < cend)
     {
-      result = scm_call_2 (kons, SCM_MAKE_CHAR (scm_i_string_ref (s, cend-1)), result);
+      result = scm_call_2 (kons, scm_c_make_char (scm_i_string_ref (s, cend-1)), result);
       cend--;
     }
 
@@ -2769,7 +2768,7 @@ SCM_DEFINE (scm_string_for_each, "string-for-each", 2, 2, 0,
 			      4, end, cend);
   while (cstart < cend)
     {
-      scm_call_1 (proc, SCM_MAKE_CHAR (scm_i_string_ref (s, cstart)));
+      scm_call_1 (proc, scm_c_make_char (scm_i_string_ref (s, cstart)));
       cstart++;
     }
 
@@ -3210,7 +3209,7 @@ SCM_DEFINE (scm_string_filter, "string-filter", 2, 2, 0,
       while (idx < cend)
 	{
 	  SCM res, ch;
-	  ch = SCM_MAKE_CHAR (scm_i_string_ref (s, idx));
+	  ch = scm_c_make_char (scm_i_string_ref (s, idx));
 	  res = scm_call_1 (char_pred, ch);
 	  if (scm_is_true (res))
 	    ls = scm_cons (ch, ls);
@@ -3345,7 +3344,7 @@ SCM_DEFINE (scm_string_delete, "string-delete", 2, 2, 0,
       idx = cstart;
       while (idx < cend)
 	{
-	  SCM res, ch = SCM_MAKE_CHAR (scm_i_string_ref (s, idx));
+	  SCM res, ch = scm_c_make_char (scm_i_string_ref (s, idx));
 	  res = scm_call_1 (char_pred, ch);
 	  if (scm_is_false (res))
 	    ls = scm_cons (ch, ls);
